pub struct RedisConfig { /* private fields */ }Expand description
Redis connection and namespace settings.
Implementations
Sourceimpl RedisConfig
impl RedisConfig
Sourcepub fn new(url: impl Into<String>) -> Self
pub fn new(url: impl Into<String>) -> Self
Creates a new Redis configuration using the default namespace and index.
Sourcepub fn with_namespace(self, namespace: impl Into<String>) -> Self
pub fn with_namespace(self, namespace: impl Into<String>) -> Self
Sets the namespace prefix used for generated Redis keys.
Sourcepub fn with_index(self, index: impl Into<String>) -> Self
pub fn with_index(self, index: impl Into<String>) -> Self
Sets the Redis index name.